<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\AxaAccredited;
use Illuminate\Http\Request;

class AxaAccreditedController extends Controller
{

    public function index(Request $request)
    {
        $accrediteds = AxaAccredited::latest()->get();
        return view('backend.modules.axa-accredited.index', compact('accrediteds'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.axa-accredited.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|unique:axa_accrediteds,name',
            'file' => 'required',
            'type' => 'required',
        ]);

        $file = $request->file;
        $file_name = $file->getClientOriginalName();
        $destination = public_path().'/uploads/axa-accredited';
        $file->move( $destination, $file_name );
        
        AxaAccredited::create([
            'name' => $request->name,
            'file' => $file_name,
            'type' => $request->type,
        ]);

        return redirect('admin/axa-accredited')->with('success', 'New Axa Accredited Provider Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $accredited = AxaAccredited::findOrFail($id);
        return view('backend.modules.axa-accredited.show', compact('accredited'));
    }

    public function edit(Request $request, $id)
    {
        $accredited = AxaAccredited::findOrFail($id);
        return view('backend.modules.axa-accredited.edit', compact('accredited'));
    }

    public function update(Request $request, $id)
    {
        $accredited = AxaAccredited::findOrFail($id);

        $request->validate([
            'name' => 'required|unique:axa_accrediteds,name,'.$id,
            'type' => 'required',
            'file' => 'required',
        ]);

        if ($request->hasFile('file')) {
    
            $file = $request->file;
            $file_name = $request->name.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/axa-accredited';
            $file->move( $destination, $file_name );
    
            $accredited->update([
                'name' => $request->name,
                'file' => $file_name,
                'type' => $request->type,
            ]);
        }

        $accredited->update([
            'name' => $request->name,
            'file' => $request->$file_name,
            'type' => $request->type,
        ]);


        return back()->with('success', 'Axa Accredited Provider Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $accredited = AxaAccredited::findOrFail($id);
        $accredited->delete();
        return back()->with('success', 'Axa Accredited Provider Deleted Successfully');
    }
}
