<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Banner;
use Illuminate\Http\Request;

class BannerController extends Controller
{
    public function index(Request $request)
    {
        $banners = Banner::all();
        return view('backend.modules.banners.index', compact('banners'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.banners.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'page' => 'required',
            'url' => 'required',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048'
        ]);

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/banners';
        $file->move( $destination, $file_name );

        Banner::create([
            'page' => $request->page,
            'url' => $request->url,
            'image' => $file_name
        ]);

        return redirect('admin/banners')->with('success', 'New Banner Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $banner = Banner::findOrFail($id);
        return view('backend.modules.banners.show', compact('banner'));
    }

    public function edit(Request $request, $id)
    {
        $banner = Banner::findOrFail($id);
        return view('backend.modules.banners.edit', compact('banner'));
    }

    public function update(Request $request, $id)
    {
        $banner = Banner::findOrFail($id);

        $request->validate([
            'page' => 'required',
            'url' => 'required',
        ]);

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/banners';
            $file->move( $destination, $file_name );

            $banner->update([
                'page' => $request->page,
                'url' => $request->url,
                'image' => $file_name
            ]);

            return back()->with('success', 'Banner Updated Successfully');
        }

        $banner->update([
            'page' => $request->page,
            'url' => $request->url,
        ]);

        return back()->with('success', 'Banner Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $banner = Banner::findOrFail($id);
        $banner->delete();
        return back()->with('success', 'Banner Deleted Successfully');
    }
}
