<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Blog;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;


class BlogController extends Controller
{
    public function index(Request $request)
    {
        $blogs = Blog::orderBy('name', 'ASC')->get();
        return view('backend.modules.blogs.index', compact('blogs'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.blogs.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            // 'position' => 'required'
            'message' => 'required',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048'
        ]);

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/blogs';
        $file->move( $destination, $file_name );

        Blog::create([
            'name' => $request->name,
            'position' => Auth::user()->role,
            'message' => $request->message,
            'image' => $file_name
        ]);

        return redirect('admin/blogs')->with('success', 'New Blog Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $blog = Blog::findOrFail($id);
        return view('backend.modules.blogs.show', compact('blog'));
    }

    public function edit(Request $request, $id)
    {
        $blog = Blog::findOrFail($id);
        return view('backend.modules.blogs.edit', compact('blog'));
    }

    public function update(Request $request, $id)
    {
        $blog = Blog::findOrFail($id);

        $request->validate([
            'name' => 'required',
            // 'position' => 'required',
            'message' => 'required',
        ]);

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/blogs';
            $file->move( $destination, $file_name );

            $blog->update([
                'name' => $request->name,
                'position' => Auth::user()->role,
                'message' => $request->message,
                'image' => $file_name
            ]);

            return back()->with('success', 'blog Updated Successfully');
        }

        $blog->update([
            'name' => $request->name,
            'position' => Auth::user()->role,
            'message' => $request->message,
        ]);

        return back()->with('success', 'blog Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $blog = Blog::findOrFail($id);
        $blog->delete();
        return back()->with('success', 'blog Deleted Successfully');
    }
}
