<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Career;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;


class CareerController extends Controller
{
    public function index(Request $request)
    {
        $careers = Career::orderBy('title', 'ASC')->get();
        return view('backend.modules.careers.index', compact('careers'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.careers.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'content' => 'required',
        ]);

        Career::create([
            'title' => $request->title,
            'content' => $request->content,
        ]);

        return redirect('admin/career')->with('success', 'New Careers Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $career = Career::findOrFail($id);
        return view('backend.modules.careers.show', compact('career'));
    }

    public function edit(Request $request, $id)
    {
        $career = Career::findOrFail($id);
        return view('backend.modules.careers.edit', compact('career'));
    }

    public function update(Request $request, $id)
    {
        $career = Career::findOrFail($id);

        $request->validate([
            'title' => 'required',
            'content' => 'required',
        ]);

        $career->update([
            'title' => $request->title,
            'content' => $request->content,
        ]);

        return back()->with('success', 'career Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $career = Career::findOrFail($id);
        $career->delete();
        return back()->with('success', 'career Deleted Successfully');
    }
}
