<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\FaqContent;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;


class FaqContentController extends Controller
{
    public function index(Request $request)
    {
        $faqContents = FaqContent::orderBy('title', 'ASC')->get();
        return view('backend.modules.faq-content.index', compact('faqContents'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.faq-content.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required',
        ]);
        
        $faqs = [];

        foreach ($request->faq_titles as $key1 => $faq_title) {
            foreach ($request->faq_contents as $key2 => $faq_content) {
                if($key1 == $key2){
                   array_push($faqs, [
                        'faq_title' => $faq_title,
                        'faq_content' => $faq_content
                   ]);
                }
            }
        }

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/faq-content';
        $file->move( $destination, $file_name );
    

        FaqContent::create([
            'title' => $request->title,
            'faqs' => json_encode($faqs),
        ]);

        return redirect('admin/faq-content')->with('success', 'New FAQ Content Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $faqContent = FaqContent::findOrFail($id);
        return view('backend.modules.faq-content.show', compact('faqContent'));
    }

    public function edit(Request $request, $id)
    {
        $faqContent = FaqContent::findOrFail($id);
        return view('backend.modules.faq-content.edit', compact('faqContent'));
    }

    public function update(Request $request, $id)
    {
        $faqContent = FaqContent::findOrFail($id);

        $request->validate([
            'title' => 'required',
        ]);
        
        $faqs = [];

        foreach ($request->faq_titles as $key1 => $faq_title) {
            foreach ($request->faq_contents as $key2 => $faq_content) {
                if($key1 == $key2){
                   array_push($faqs, [
                        'faq_title' => $faq_title,
                        'faq_content' => $faq_content
                   ]);
                }
            }
        }

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/faq-content';
            $file->move( $destination, $file_name );

            $faqContent->update([
                'title' => $request->title,
                'faqs' => json_encode($faqs),
            ]);

            return back()->with('success', 'FAQ Content Updated Successfully');
        }

        

        $faqContent->update([
            'title' => $request->title,
            'faqs' => json_encode($faqs),
        ]);

        return back()->with('success', 'FAQ Content Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $faqContent = FaqContent::findOrFail($id);
        $faqContent->delete();
        return back()->with('success', 'FAQ Content Deleted Successfully');
    }
}
