<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\HmoProvider;
use Illuminate\Http\Request;

class HmoProviderController extends Controller
{

    public function index(Request $request)
    {
        $providers = HmoProvider::where('slug', null)->orderBy('name', 'ASC')->get();
        return view('backend.modules.hmo-providers.index', compact('providers'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.hmo-providers.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|unique:hmo_providers,name',
            // 'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048',
            'formula_semiannual' => 'required|between:0,99.99',
            'formula_quarter' => 'required|between:0,99.99'
        ]);

        // $file = $request->image;
        // $file_name = time().'.'.$file->getClientOriginalExtension();
        // $destination = public_path().'/uploads/providers';
        // $file->move( $destination, $file_name );

        HmoProvider::create([
            'name' => $request->name,
            // 'image' => $file_name,
            'formula_semiannual' => $request->formula_semiannual,
            'formula_quarter' => $request->formula_quarter,
        ]);

        return back()->with('success', 'New Provider Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $provider = HmoProvider::findOrFail($id);
        return view('backend.modules.hmo-providers.show', compact('provider'));
    }

    public function edit(Request $request, $id)
    {
        $provider = HmoProvider::findOrFail($id);
        return view('backend.modules.hmo-providers.edit', compact('provider'));
    }

    public function update(Request $request, $id)
    {
        $provider = HmoProvider::findOrFail($id);

        $request->validate([
            // 'image' => 'image|mimes:jpeg,jpg,png,gif,svg|max:5048',
            'name' => 'required|unique:hmo_providers,name,' . $id,
            'formula_semiannual' => 'required|digits_between:0,99.99',
            'formula_quarter' => 'required|digits_between:0,99.99',
        ]);

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/providers';
            $file->move( $destination, $file_name );

            $provider->update([
                'name' => $request->name,
                // 'image' => $file_name,
                'formula_semiannual' => $request->formula_semiannual,
                'formula_quarter' => $request->formula_quarter,
            ]);

            return back()->with('success', 'Provider Updated Successfully');
        }

        $provider->update([
            'name' => $request->name,
            'formula_semiannual' => $request->formula_semiannual,
            'formula_quarter' => $request->formula_quarter,
        ]);

        return back()->with('success', 'Provider Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $provider = HmoProvider::findOrFail($id);

        $provider->update([
            'active' => 0
        ]);

        return back()->with('success', 'Provider Deleted Successfully');
    }


}
