<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Nonlife;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;


class NonlifeController extends Controller
{
    public function index(Request $request)
    {
        $nonlives = Nonlife::orderBy('title', 'ASC')->get();
        return view('backend.modules.nonlife.index', compact('nonlives'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.nonlife.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'content' => 'required',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048',
        ]);

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/nonlife';
        $file->move( $destination, $file_name );

        Nonlife::create([
            'title' => $request->title,
            'content' => $request->content,
            'image' => $file_name,
            'has_form' => $request->has_form == 'on' ? 1 : 0,
        ]);

        return redirect('admin/nonlife')->with('success', 'New Nonlife Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $nonlife = Nonlife::findOrFail($id);
        return view('backend.modules.nonlife.show', compact('nonlife'));
    }

    public function edit(Request $request, $id)
    {
        $nonlife = Nonlife::findOrFail($id);
        return view('backend.modules.nonlife.edit', compact('nonlife'));
    }

    public function update(Request $request, $id)
    {
        $nonlife = Nonlife::findOrFail($id);

        $request->validate([
            'title' => 'required',
            'content' => 'required',
        ]);

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/nonlife';
            $file->move( $destination, $file_name );

            $nonlife->update([
                'title' => $request->title,
                'position' => Auth::user()->role,
                'content' => $request->content,
                'image' => $file_name,
                'has_form' => $request->has_form == 'on' ? 1 : 0,
            ]);

            return back()->with('success', 'Nonlife Updated Successfully');
        }

        $nonlife->update([
            'title' => $request->title,
            'position' => Auth::user()->role,
            'content' => $request->content,
            'has_form' => $request->has_form == 'on' ? 1 : 0,
        ]);

        return back()->with('success', 'Nonlife Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $nonlife = Nonlife::findOrFail($id);
        $nonlife->delete();
        return back()->with('success', 'Nonlife Deleted Successfully');
    }
}
