<?php

namespace App\Http\Controllers\Backend\Plan;

use App\Models\Plan\Max;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class MaxController extends Controller
{
    public function index(Request $request)
    {
        $plans = Max::latest()->get();
        return view('backend.modules.plan.max.index', compact('plans'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.plan.max.create');
    }

    public function store(Request $request)
    {
        // return $request;
        $request->validate([
            'provider_name' => 'required',
            'plan_name' => 'required',
            'image' => 'required',
        ]);

        $price_smoke = [
            'non_smoker' => $request->price_nonsmoker,
            'smoker' => $request->price_smoker
        ];
        $price_smoke_gender = [
            'male' => [
                'non_smoker' => $request->price_nonsmoker_male,
                'smoker' => $request->price_smoker_male,
            ],
            'female' => [
                'non_smoker' => $request->price_nonsmoker_female,
                'smoker' => $request->price_smoker_female,
            ]
        ];

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/plan';
        $file->move( $destination, $file_name );

        // return 1;
        Max::create([
            'provider_name' => $request->provider_name,
            'plan_name' => $request->plan_name,
            'image' => $file_name,

            // 'room_board' => $request->room_board,
            // 'benefit_limit_type' => $request->benefit_limit_type,
            // 'benefit_limit' => $request->benefit_limit,
            
            'payment_terms' => $request->payment_terms,
            'required_gender' => $request->required_gender == 'on' ? 1 : 0,
            'required_smoke' => $request->required_smoke == 'on' ? 1 : 0,
            'required_gender_smoke' => $request->required_gender_smoke == 'on' ? 1 : 0,
            'price' => json_encode($request->price),
            'price_male' => json_encode($request->price_male),
            'price_female' => json_encode($request->price_female),
            'price_smoke' => json_encode($price_smoke),
            'price_smoke_gender' => json_encode($price_smoke_gender),
        ]);

        return redirect('admin/plan/max')->with([
            'success' => 'New Plan Added Successfully!'
        ]);
    }


    public function show(Request $request, $id)
    {
        $plan = Max::findOrFail($id);
        return view('backend.modules.plan.max.show', compact('plan'));
    }

    public function edit(Request $request, $id)
    {
        $plan = Max::findOrFail($id);
        return view('backend.modules.plan.max.edit', compact('plan'));
    }


    public function update(Request $request, $id)
    {
        $plan = Max::findOrFail($id);

        $request->validate([
            'provider_name' => 'required',
            'plan_name' => 'required',
        ]);

        $price_smoke = [
            'non_smoker' => $request->price_nonsmoker,
            'smoker' => $request->price_smoker
        ];
        $price_smoke_gender = [
            'male' => [
                'non_smoker' => $request->price_nonsmoker_male,
                'smoker' => $request->price_smoker_male,
            ],
            'female' => [
                'non_smoker' => $request->price_nonsmoker_female,
                'smoker' => $request->price_smoker_female,
            ]
        ];

        $price_smoke_null = [
            'non_smoker' => [],
            'smoker' => []
        ];
        $price_smoke_gender_null = [
            'male' => [
                'non_smoker' => [],
                'smoker' => [],
            ],
            'female' => [
                'non_smoker' => [],
                'smoker' => [],
            ]
        ];

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/plan';
            $file->move( $destination, $file_name );

            $plan->update([
                'provider_name' => $request->provider_name,
                'plan_name' => $request->plan_name,
                'image' => $file_name,
                'plan_price' => $request->plan_price,

                // 'plan_payment' => $request->plan_payment,
                // 'benefit_limit_type' => $request->benefit_limit_type,
                // 'benefit_limit' => $request->benefit_limit,
                
                'payment_terms' => $request->payment_terms,
                'required_gender' => $request->required_gender == 'on' ? 1 : 0,
                'required_smoke' => $request->required_smoke == 'on' ? 1 : 0,
                'required_gender_smoke' => $request->required_gender_smoke == 'on' ? 1 : 0,
                'price' => $request->required_smoke == 'on' || $request->required_gender == 'on' ? json_encode(null) : json_encode($request->price),
                'price_male' => $request->required_gender == 'on' ? json_encode($request->price_male) : json_encode(null),
                'price_female' => $request->required_gender == 'on' ? json_encode($request->price_female) : json_encode(null),
                'price_smoke' => $request->required_smoke == 'on' && $request->required_smoke_gender != 'on' ? json_encode($price_smoke) : json_encode($price_smoke_null),
                'price_smoke_gender' => $request->required_smoke == 'on' && $request->required_gender_smoke == 'on' ? json_encode($price_smoke_gender) : json_encode($price_smoke_gender_null),
            ]);

            return back()->with('success', 'Plan Updated Successfully');
        }
        
        $plan->update([
            'provider_name' => $request->provider_name,
            'plan_name' => $request->plan_name,
            'plan_price' => $request->plan_price,

            // 'plan_payment' => $request->plan_payment,
            // 'benefit_limit_type' => $request->benefit_limit_type,
            // 'benefit_limit' => $request->benefit_limit,
            
            'payment_terms' => $request->payment_terms,
            'required_gender' => $request->required_gender == 'on' ? 1 : 0,
            'required_smoke' => $request->required_smoke == 'on' ? 1 : 0,
            'required_gender_smoke' => $request->required_gender_smoke == 'on' ? 1 : 0,
            'price' => $request->required_smoke == 'on' || $request->required_gender == 'on' ? json_encode(null) : json_encode($request->price),
            'price_male' => $request->required_gender == 'on' ? json_encode($request->price_male) : json_encode(null),
            'price_female' => $request->required_gender == 'on' ? json_encode($request->price_female) : json_encode(null),
            'price_smoke' => $request->required_smoke == 'on' && $request->required_smoke_gender != 'on' ? json_encode($price_smoke) : json_encode($price_smoke_null),
            'price_smoke_gender' => $request->required_smoke == 'on' && $request->required_gender_smoke == 'on' ? json_encode($price_smoke_gender) : json_encode($price_smoke_gender_null),
        ]);

        return back()->with([
            'success' => 'Plan Updated Successfully!'
        ]);


    }


    public function destroy(Request $request, $id)
    {
        Max::find($id)->delete();
        return back()->with([
            'success' => 'Plan Deleted Successfully!'
        ]);
    }

    public function age(Request $request, $type = null, $action = null){
        // return $request;
        if($type == 'age'){
            if($action == 'add'){
                // return count(session('ages'));
                session()->push('ages', count(session('ages')));
            }else if($action == 'minus'){
                $ages = session('ages');
                array_pop($ages);
                session()->put('ages', $ages);
            }
        }
        return back();

    }

}
