<?php

namespace App\Http\Controllers\Backend;

use App\Models\Plan;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class PlanController extends Controller
{
    public function index(Request $request)
    {
        $plans = Plan::latest()->get();
        return view('backend.modules.plans.index', compact('plans'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.plans.create');
    }

    public function store(Request $request)
    {
        // return $request;
        $request->validate([
            'provider_type' => 'required',
            'provider_name' => 'required',
            'plan_name' => 'required',
            'image' => 'required',
        ]);

        // $price = $request->price;
        // $price_male = $request->price_male;
        // $price_female = $request->price_female;

        // if($request->required_gender){
        //     $price_male = 0;
        //     $price_female = 0;
        // }else{
        //     $price = 0;
        // }
        

        $price_smoke = [
            'non_smoker' => $request->price_nonsmoker,
            'smoker' => $request->price_smoker
        ];
        $price_smoke_gender = [
            'male' => [
                'non_smoker' => $request->price_nonsmoker_male,
                'smoker' => $request->price_smoker_male,
            ],
            'female' => [
                'non_smoker' => $request->price_nonsmoker_female,
                'smoker' => $request->price_smoker_female,
            ]
        ];

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/plan';
        $file->move( $destination, $file_name );

        // return 1;
        Plan::create([
            'provider_type' => $request->provider_type,
            'provider_name' => $request->provider_name,
            'plan_name' => $request->plan_name,
            'image' => $file_name,
            'plan_type' => $request->plan_type,
            'max_age' => $request->max_age,
            'benefit_type' => $request->benefit_type,
            'room_board' => $request->room_board,
            'dental' => $request->dental,
            'benefit_limit_type' => $request->benefit_limit_type,
            'benefit_limit' => $request->benefit_limit,
            'plan_link' => $request->plan_link,
            'accidental_death_disability' => $request->accidental_death_disability,
            'mbl_per_illness_per_year' => $request->mbl_per_illness_per_year,
            'abl_annual_benefit_limit' => $request->abl_annual_benefit_limit,
            'pre_existing_conditions' => $request->pre_existing_conditions,
            'outpatient_care' => $request->outpatient_care,
            'dental_care' => $request->dental_care,
            'annual_physical_exam' => $request->annual_physical_exam,
            'major_hospital_access' => $request->major_hospital_access,
            'age_eligibility' => $request->age_eligibility,
            'life_insurance_with_ad' => $request->life_insurance_with_ad,
            'ambulance_service' => $request->ambulance_service,
            'travel_assistance' => $request->travel_assistance,
            'non_accredited_hospitals' => $request->non_accredited_hospitals,
            'payment_terms' => $request->payment_terms,
            'required_gender' => $request->required_gender == 'on' ? 1 : 0,
            'required_smoke' => $request->required_smoke == 'on' ? 1 : 0,
            'required_gender_smoke' => $request->required_gender_smoke == 'on' ? 1 : 0,
            'price' => json_encode($request->price),
            'price_male' => json_encode($request->price_male),
            'price_female' => json_encode($request->price_female),
            'price_smoke' => json_encode($price_smoke),
            'price_smoke_gender' => json_encode($price_smoke_gender),
        ]);

        return redirect('admin/plans')->with([
            'success' => 'New Plan Added Successfully!'
        ]);
    }


    public function show(Request $request, $id)
    {
        $plan = Plan::findOrFail($id);
        return view('backend.modules.plans.show', compact('plan'));
    }

    public function edit(Request $request, $id)
    {
        $plan = Plan::findOrFail($id);
        return view('backend.modules.plans.edit', compact('plan'));
    }


    public function update(Request $request, $id)
    {
        $plan = Plan::findOrFail($id);

        $request->validate([
            'provider_type' => 'required',
            'provider_name' => 'required',
            'plan_name' => 'required',
        ]);

        $price_smoke = [
            'non_smoker' => $request->price_nonsmoker,
            'smoker' => $request->price_smoker
        ];
        $price_smoke_gender = [
            'male' => [
                'non_smoker' => $request->price_nonsmoker_male,
                'smoker' => $request->price_smoker_male,
            ],
            'female' => [
                'non_smoker' => $request->price_nonsmoker_female,
                'smoker' => $request->price_smoker_female,
            ]
        ];

        $price_smoke_null = [
            'non_smoker' => [],
            'smoker' => []
        ];
        $price_smoke_gender_null = [
            'male' => [
                'non_smoker' => [],
                'smoker' => [],
            ],
            'female' => [
                'non_smoker' => [],
                'smoker' => [],
            ]
        ];

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/plan';
            $file->move( $destination, $file_name );

            $plan->update([
                'provider_type' => $request->provider_type,
                'provider_name' => $request->provider_name,
                'plan_name' => $request->plan_name,
                'image' => $file_name,
                'plan_price' => $request->plan_price,
                'plan_type' => $request->plan_type,
                'max_age' => $request->max_age,
                'plan_payment' => $request->plan_payment,
                'benefit_type' => $request->benefit_type,
                'room_board' => $request->room_board,
                'basic_fees' => $request->basic_fees,
                'dental' => $request->dental,
                'benefit_limit_type' => $request->benefit_limit_type,
                'benefit_limit' => $request->benefit_limit,
                'plan_link' => $request->plan_link,
                'accidental_death_disability' => $request->accidental_death_disability,
                'mbl_per_illness_per_year' => $request->mbl_per_illness_per_year,
                'abl_annual_benefit_limit' => $request->abl_annual_benefit_limit,
                'pre_existing_conditions' => $request->pre_existing_conditions,
                'outpatient_care' => $request->outpatient_care,
                'dental_care' => $request->dental_care,
                'annual_physical_exam' => $request->annual_physical_exam,
                'major_hospital_access' => $request->major_hospital_access,
                'age_eligibility' => $request->age_eligibility,
                'life_insurance_with_ad' => $request->life_insurance_with_ad,
                'ambulance_service' => $request->ambulance_service,
                'travel_assistance' => $request->travel_assistance,
                'non_accredited_hospitals' => $request->non_accredited_hospitals,
                'payment_terms' => $request->payment_terms,
                'required_gender' => $request->required_gender == 'on' ? 1 : 0,
                'required_smoke' => $request->required_smoke == 'on' ? 1 : 0,
                'required_gender_smoke' => $request->required_gender_smoke == 'on' ? 1 : 0,
                'price' => $request->required_smoke == 'on' || $request->required_gender == 'on' ? json_encode(null) : json_encode($request->price),
                'price_male' => $request->required_gender == 'on' ? json_encode($request->price_male) : json_encode(null),
                'price_female' => $request->required_gender == 'on' ? json_encode($request->price_female) : json_encode(null),
                'price_smoke' => $request->required_smoke == 'on' && $request->required_smoke_gender != 'on' ? json_encode($price_smoke) : json_encode($price_smoke_null),
                'price_smoke_gender' => $request->required_smoke == 'on' && $request->required_gender_smoke == 'on' ? json_encode($price_smoke_gender) : json_encode($price_smoke_gender_null),
            ]);

            return back()->with('success', 'Plan Updated Successfully');
        }
        
        $plan->update([
            'provider_type' => $request->provider_type,
            'provider_name' => $request->provider_name,
            'plan_name' => $request->plan_name,
            'plan_price' => $request->plan_price,
            'plan_type' => $request->plan_type,
            'max_age' => $request->max_age,
            'plan_payment' => $request->plan_payment,
            'benefit_type' => $request->benefit_type,
            'room_board' => $request->room_board,
            'basic_fees' => $request->basic_fees,
            'dental' => $request->dental,
            'benefit_limit_type' => $request->benefit_limit_type,
            'benefit_limit' => $request->benefit_limit,
            'plan_link' => $request->plan_link,
            'accidental_death_disability' => $request->accidental_death_disability,
            'mbl_per_illness_per_year' => $request->mbl_per_illness_per_year,
            'abl_annual_benefit_limit' => $request->abl_annual_benefit_limit,
            'pre_existing_conditions' => $request->pre_existing_conditions,
            'outpatient_care' => $request->outpatient_care,
            'dental_care' => $request->dental_care,
            'annual_physical_exam' => $request->annual_physical_exam,
            'major_hospital_access' => $request->major_hospital_access,
            'age_eligibility' => $request->age_eligibility,
            'life_insurance_with_ad' => $request->life_insurance_with_ad,
            'ambulance_service' => $request->ambulance_service,
            'travel_assistance' => $request->travel_assistance,
            'non_accredited_hospitals' => $request->non_accredited_hospitals,
            'payment_terms' => $request->payment_terms,
            'required_gender' => $request->required_gender == 'on' ? 1 : 0,
            'required_smoke' => $request->required_smoke == 'on' ? 1 : 0,
            'required_gender_smoke' => $request->required_gender_smoke == 'on' ? 1 : 0,
            'price' => $request->required_smoke == 'on' || $request->required_gender == 'on' ? json_encode(null) : json_encode($request->price),
            'price_male' => $request->required_gender == 'on' ? json_encode($request->price_male) : json_encode(null),
            'price_female' => $request->required_gender == 'on' ? json_encode($request->price_female) : json_encode(null),
            'price_smoke' => $request->required_smoke == 'on' && $request->required_smoke_gender != 'on' ? json_encode($price_smoke) : json_encode($price_smoke_null),
            'price_smoke_gender' => $request->required_smoke == 'on' && $request->required_gender_smoke == 'on' ? json_encode($price_smoke_gender) : json_encode($price_smoke_gender_null),
        ]);

        return back()->with([
            'success' => 'Plan Updated Successfully!'
        ]);


    }


    public function destroy(Request $request, $id)
    {
        Plan::find($id)->delete();
        return back()->with([
            'success' => 'Plan Deleted Successfully!'
        ]);
    }

    public function age(Request $request, $type = null, $action = null){
        // return $request;
        if($type == 'age'){
            if($action == 'add'){
                // return count(session('ages'));
                session()->push('ages', count(session('ages')));
            }else if($action == 'minus'){
                $ages = session('ages');
                array_pop($ages);
                session()->put('ages', $ages);
            }
        }
        return back();

    }

}
