<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\PrepaidProvider;
use Illuminate\Http\Request;

class PrepaidProviderController extends Controller
{

    public function index(Request $request)
    {
        $providers = PrepaidProvider::orderBy('name', 'ASC')->get();
        return view('backend.modules.prepaid-providers.index', compact('providers'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.prepaid-providers.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|unique:prepaid_providers,name',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048'
        ]);

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/providers';
        $file->move( $destination, $file_name );

        PrepaidProvider::create([
            'name' => $request->name,
            'image' => $file_name,
            'hide' => $request->hide === 'on' ? 1 : 0,
        ]);

        return redirect('admin/providers')->with('success', 'New Provider Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $provider = PrepaidProvider::findOrFail($id);
        return view('backend.modules.prepaid-providers.show', compact('provider'));
    }

    public function edit(Request $request, $id)
    {
        $provider = PrepaidProvider::findOrFail($id);
        return view('backend.modules.prepaid-providers.edit', compact('provider'));
    }

    public function update(Request $request, $id)
    {
        $provider = PrepaidProvider::findOrFail($id);

        $request->validate([
            'name' => 'required|unique:prepaid_providers,name,' . $id,
        ]);

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/providers';
            $file->move( $destination, $file_name );

            $provider->update([
                'name' => $request->name,
                'image' => $file_name
            ]);

            return back()->with('success', 'Provider Updated Successfully');
        }

        $provider->update([
            'name' => $request->name,
            'hide' => $request->hide === 'on' ? 1 : 0,
        ]);

        return back()->with('success', 'Provider Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $provider = PrepaidProvider::findOrFail($id);

        $provider->update([
            'active' => 0
        ]);

        return back()->with('success', 'Provider Deleted Successfully');
    }


}
