<?php

namespace App\Http\Controllers\Backend;

use App\Models\Product;
use App\Models\PrepaidProvider;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class ProductController extends Controller
{
    public function index(Request $request)
    {
        $products = Product::orderBy('product_name', 'ASC')->get();
        return view('backend.modules.products.index', compact('products'));
    }

    public function create(Request $request)
    {
        $providers = PrepaidProvider::orderBy('name', 'ASC')->get();
        return view('backend.modules.products.create', compact('providers'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'provider_id' => 'required|exists:providers,id',
            'card_image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048',
            'product_name' => 'required',
            'usage' => 'required',
            'price' => 'required|numeric',
            'limit' => 'required|numeric',
            'physical_card_option' => 'required',
            'description' => 'required',
            'room_type' => 'required',
        ]);

        $file = $request->card_image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/personal/cards';
        $file->move( $destination, $file_name );

        Product::create([
            'provider_id'           => $request->provider_id,
            'product_type'          => 'personal',
            'card_img'              => $file_name,
            'product_name'          => $request->product_name,
            'price'                 => $request->price,
            'limit'                 => $request->limit,
            'usage'                 => $request->usage,
            'physical_card_option'  => $request->physical_card_option,
            'description'           => $request->description,
            'digital_card'          => $request->digital_card === 'on' ? 1 : 0 ,
            'covid_19'              => $request->covid_19 === 'on' ? 1 : 0 ,
            'exist_illness'         => $request->exist_illness === 'on' ? 1 : 0 ,
            'for_kid'               => $request->for_kid === 'on' ? 1 : 0 ,
            'for_adult'             => $request->for_adult === 'on' ? 1 : 0 ,
            'for_senior'            => $request->for_senior === 'on' ? 1 : 0 ,
            'er_only'               => $request->er_only === 'on' ? 1 : 0 ,
            'er_coverage'           => $request->er_coverage === 'on' ? 1 : 0 ,
            'unli_consult'          => $request->unli_consult === 'on' ? 1 : 0 ,
            'unli_lab_test'         => $request->unli_lab_test === 'on' ? 1 : 0 ,
            'with_major_hospital'   => $request->with_major_hospital === 'on' ? 1 : 0 ,
            'mental_health'         => $request->mental_health === 'on' ? 1 : 0 ,
            'is_available'          => $request->is_available === 'on' ? 1 : 0 ,
            'hide'                  => $request->hide === 'on' ? 1 : 0 ,
            'rank'                  => $request->rank === 'on' ? 1 : 0 ,
            'room_type'             => $request->room_type
        ]);

        return redirect('admin/products')->with([
            'success' => 'New Product Added Successfully!'
        ]);
    }


    public function show(Request $request, $id)
    {
        $product = Product::findOrFail($id);
        $providers = PrepaidProvider::orderBy('name', 'ASC')->get();
        return view('backend.modules.products.show', compact('product','providers'));
    }

    public function edit(Request $request, $id)
    {
        $product = Product::findOrFail($id);
        $providers = PrepaidProvider::orderBy('name', 'ASC')->get();
        return view('backend.modules.products.edit', compact('product','providers'));
    }


    public function update(Request $request, $id)
    {
        $product = Product::findOrFail($id);

        $request->validate([
            'provider_id' => 'required|exists:providers,id',
            'product_name' => 'required',
            'usage' => 'required',
            'price' => 'required|numeric',
            'limit' => 'required|numeric',
            'description' => 'required',
            'room_type' => 'required'
        ]);
        
        if ($request->hasFile('card_image')) {
            $file = $request->card_image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/personal/cards';
            $file->move( $destination, $file_name );

            $product->update([
                'provider_id'           => $request->provider_id,
                'card_img'              => $file_name,
                'product_name'          => $request->product_name,
                'limit'                 => $request->limit,
                'usage'                 => $request->usage,
                'physical_card_option'  => $request->physical_card_option,
                'price'                 => $request->price,
                'description'           => $request->description,
                'digital_card'          => $request->digital_card === 'on' ? 1 : 0 ,
                'covid_19'              => $request->covid_19 === 'on' ? 1 : 0 ,
                'exist_illness'         => $request->exist_illness === 'on' ? 1 : 0 ,
                'for_kid'               => $request->for_kid === 'on' ? 1 : 0 ,
                'for_adult'             => $request->for_adult === 'on' ? 1 : 0 ,
                'for_senior'            => $request->for_senior === 'on' ? 1 : 0 ,
                'er_only'               => $request->er_only === 'on' ? 1 : 0 ,
                'er_coverage'           => $request->er_coverage === 'on' ? 1 : 0 ,
                'unli_consult'          => $request->unli_consult === 'on' ? 1 : 0 ,
                'unli_lab_test'         => $request->unli_lab_test === 'on' ? 1 : 0 ,
                'with_major_hospital'   => $request->with_major_hospital === 'on' ? 1 : 0 ,
                'mental_health'         => $request->mental_health === 'on' ? 1 : 0 ,
                'is_available'          => $request->is_available === 'on' ? 1 : 0 ,
                'hide'                  => $request->hide === 'on' ? 1 : 0 ,
                'rank'                  => $request->rank === 'on' ? 1 : 0 ,
                'room_type'             => $request->room_type
            ]);

            return back()->with([
                'success' => 'Product Updated Successfully!'
            ]);
        }

        $product->update([
            'provider_id'           => $request->provider_id,
            'product_name'          => $request->product_name,
            'price'                 => $request->price,
            'limit'                 => $request->limit,
            'usage'                 => $request->usage,
            'physical_card_option'  => $request->physical_card_option,
            'description'           => $request->description,
            'digital_card'          => $request->digital_card === 'on' ? 1 : 0 ,
            'covid_19'              => $request->covid_19 === 'on' ? 1 : 0 ,
            'exist_illness'         => $request->exist_illness === 'on' ? 1 : 0 ,
            'for_kid'               => $request->for_kid === 'on' ? 1 : 0 ,
            'for_adult'             => $request->for_adult === 'on' ? 1 : 0 ,
            'for_senior'            => $request->for_senior === 'on' ? 1 : 0 ,
            'er_only'               => $request->er_only === 'on' ? 1 : 0 ,
            'er_coverage'           => $request->er_coverage === 'on' ? 1 : 0 ,
            'unli_consult'          => $request->unli_consult === 'on' ? 1 : 0 ,
            'unli_lab_test'         => $request->unli_lab_test === 'on' ? 1 : 0 ,
            'with_major_hospital'   => $request->with_major_hospital === 'on' ? 1 : 0 ,
            'mental_health'         => $request->mental_health === 'on' ? 1 : 0 ,
            'is_available'          => $request->is_available === 'on' ? 1 : 0 ,
            'hide'                  => $request->hide === 'on' ? 1 : 0 ,
            'rank'                  => $request->rank === 'on' ? 1 : 0 ,
            'room_type'             => $request->room_type
        ]);

        return back()->with([
            'success' => 'Product Updated Successfully!'
        ]);


    }


    public function destroy(Request $request, $id)
    {
        Product::find($id)->delete();
        return back()->with([
            'success' => 'Product Deleted Successfully!'
        ]);
    }

}
