<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\SupportCenter;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;


class SupportCenterController extends Controller
{
    public function index(Request $request)
    {
        $supportCenters = SupportCenter::orderBy('title', 'ASC')->get();
        return view('backend.modules.support-center.index', compact('supportCenters'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.support-center.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048'
        ]);
        
        $faqs = [];

        foreach ($request->faq_titles as $key1 => $faq_title) {
            foreach ($request->faq_contents as $key2 => $faq_content) {
                if($key1 == $key2){
                   array_push($faqs, [
                        'faq_title' => $faq_title,
                        'faq_content' => $faq_content
                   ]);
                }
            }
        }

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/support-center';
        $file->move( $destination, $file_name );
    

        SupportCenter::create([
            'title' => $request->title,
            'faqs' => json_encode($faqs),
            'image' => $file_name
        ]);

        return redirect('admin/support-center')->with('success', 'New Support Center Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $supportCenter = SupportCenter::findOrFail($id);
        return view('backend.modules.support-center.show', compact('supportCenter'));
    }

    public function edit(Request $request, $id)
    {
        $supportCenter = SupportCenter::findOrFail($id);
        return view('backend.modules.support-center.edit', compact('supportCenter'));
    }

    public function update(Request $request, $id)
    {
        $supportCenter = SupportCenter::findOrFail($id);

        $request->validate([
            'title' => 'required',
        ]);
        
        $faqs = [];

        foreach ($request->faq_titles as $key1 => $faq_title) {
            foreach ($request->faq_contents as $key2 => $faq_content) {
                if($key1 == $key2){
                   array_push($faqs, [
                        'faq_title' => $faq_title,
                        'faq_content' => $faq_content
                   ]);
                }
            }
        }

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/support-center';
            $file->move( $destination, $file_name );

            $supportCenter->update([
                'title' => $request->title,
                'faqs' => json_encode($faqs),
                'image' => $file_name
            ]);

            return back()->with('success', 'Support Center Updated Successfully');
        }

        

        $supportCenter->update([
            'title' => $request->title,
            'faqs' => json_encode($faqs),
        ]);

        return back()->with('success', 'Support Center Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $supportCenter = SupportCenter::findOrFail($id);
        $supportCenter->delete();
        return back()->with('success', 'Support Center Deleted Successfully');
    }
}
