<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Testimonial;
use Illuminate\Http\Request;

class TestimonialController extends Controller
{
    public function index(Request $request)
    {
        $testimonials = Testimonial::orderBy('name', 'ASC')->get();
        return view('backend.modules.testimonials.index', compact('testimonials'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.testimonials.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'position' => 'required',
            'message' => 'required',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048'
        ]);

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/testimonials';
        $file->move( $destination, $file_name );

        Testimonial::create([
            'name' => $request->name,
            'position' => $request->position,
            'message' => $request->message,
            'image' => $file_name
        ]);

        return redirect('admin/testimonials')->with('success', 'New Testimonial Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $testimonial = Testimonial::findOrFail($id);
        return view('backend.modules.testimonials.show', compact('testimonial'));
    }

    public function edit(Request $request, $id)
    {
        $testimonial = Testimonial::findOrFail($id);
        return view('backend.modules.testimonials.edit', compact('testimonial'));
    }

    public function update(Request $request, $id)
    {
        $testimonial = Testimonial::findOrFail($id);

        $request->validate([
            'name' => 'required',
            'position' => 'required',
            'message' => 'required',
        ]);

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/testimonials';
            $file->move( $destination, $file_name );

            $testimonial->update([
                'name' => $request->name,
                'position' => $request->position,
                'message' => $request->message,
                'image' => $file_name
            ]);

            return back()->with('success', 'Testimonial Updated Successfully');
        }

        $testimonial->update([
            'name' => $request->name,
            'position' => $request->position,
            'message' => $request->message,
        ]);

        return back()->with('success', 'Testimonial Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $testimonial = Testimonial::findOrFail($id);
        $testimonial->delete();
        return back()->with('success', 'Testimonial Deleted Successfully');
    }
}
