<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\TrustedProvider;
use Illuminate\Http\Request;


class TrustedProviderController extends Controller
{
    public function index(Request $request)
    {
        $trustedProviders = TrustedProvider::latest()->get();
        return view('backend.modules.trusted-providers.index', compact('trustedProviders'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.trusted-providers.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'heading' => 'required',
            'description' => 'required',
            'card_image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048',
            'modal_image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:30000'
        ]);

        $card_image = $this->fileUpload('/uploads/trusted-providers', $request->card_image);
        $modal_image = $this->fileUpload('/uploads/trusted-providers', $request->modal_image);
        
        TrustedProvider::create([
            'heading' => $request->heading,
            'description' => $request->description,
            'card_image' => $card_image,
            'modal_image' => $modal_image,
        ]);

        return redirect('admin/trusted-providers')->with('success', 'New Trusted Provider Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $trustedProvider = TrustedProvider::findOrFail($id);
        return view('backend.modules.trusted-providers.edit', compact('trustedProvider'));
    }

    public function edit(Request $request, $id)
    {
        $trustedProvider = TrustedProvider::findOrFail($id);
        return view('backend.modules.trusted-providers.edit', compact('trustedProvider'));
    }

    public function update(Request $request, $id)
    {
        $trustedProvider = TrustedProvider::findOrFail($id);
        // dd($request->card_image);
        if ($request->hasFile('card_image')) {

            $card_image = $this->fileUpload('/uploads/trusted-providers', $request->card_image);

            $trustedProvider->update([
                'heading' => $request->heading,
                'description' => $request->description,
                'card_image' => $card_image,
            ]);
            back()->with('success', 'Trusted Providers Updated Successfully');

        }
        if ($request->hasFile('modal_image')) {

            $modal_image = $this->fileUpload('/uploads/trusted-providers', $request->modal_image);

            $trustedProvider->update([
                'heading' => $request->heading,
                'description' => $request->description,
                'modal_image' => $modal_image,
            ]);
            
            back()->with('success', 'Trusted Providers Updated Successfully');

        }

        $trustedProvider->update([
            'heading' => $request->heading,
            'description' => $request->description,
        ]);

        return back()->with('success', 'Trusted Providers Updated Successfully');
    }
    public function destroy(Request $request, $id)
    {
        $accredited = TrustedProvider::findOrFail($id);
        $accredited->delete();
        return back()->with('success', 'Trusted Providers Deleted Successfully');
    }
    public function fileUpload($path, $file){

        $file_name = time().'-'.$file->getClientOriginalName();
        $destination = public_path().$path;
        $file->move( $destination, $file_name );
        return $file_name;

    }

}
