<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\TypeOfInsurance;
use Illuminate\Http\Request;

class TypeOfInsuranceController extends Controller
{
    public function index(Request $request)
    {
        $typeOfInsurances = TypeOfInsurance::all();
        return view('backend.modules.type-of-insurance.index', compact('typeOfInsurances'));
    }

    public function create(Request $request)
    {
        return view('backend.modules.type-of-insurance.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'url' => 'required',
            'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:5048',
        ]);

        $file = $request->image;
        $file_name = time().'.'.$file->getClientOriginalExtension();
        $destination = public_path().'/uploads/type-of-insurance';
        $file->move( $destination, $file_name );

        TypeOfInsurance::create([
            'url' => $request->url,
            'image' => $file_name,
            'details' => $request->details
        ]);

        return redirect('admin/type-of-insurance')->with('success', 'New Type of Insurance Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $typeOfInsurance = TypeOfInsurance::findOrFail($id);
        return view('backend.modules.type-of-insurance.show', compact('typeOfInsurance'));
    }

    public function edit(Request $request, $id)
    {
        $typeOfInsurance = TypeOfInsurance::findOrFail($id);
        return view('backend.modules.type-of-insurance.edit', compact('typeOfInsurance'));
    }

    public function update(Request $request, $id)
    {
        $typeOfInsurance = TypeOfInsurance::findOrFail($id);

        $request->validate([
            'image' => 'image|mimes:jpeg,jpg,png,gif,svg|max:5048'

        ]);

        if ($request->hasFile('image')) {
            $file = $request->image;
            $file_name = time().'.'.$file->getClientOriginalExtension();
            $destination = public_path().'/uploads/type-of-insurance';
            $file->move( $destination, $file_name );

            $typeOfInsurance->update([
                'url' => $request->url,
                'image' => $file_name,
                'details' => $request->details

            ]);

            return back()->with('success', 'Type of Insurance Updated Successfully');
        }

        $typeOfInsurance->update([
            'url' => $request->url,
            'details' => $request->details
        ]);

        return back()->with('success', 'Type of Insurance Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $typeOfInsurance = TypeOfInsurance::findOrFail($id);
        $typeOfInsurance->delete();
        return back()->with('success', 'Type of Insurance Deleted Successfully');
    }
}
