<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Voucher;
use App\Models\Product;
use Illuminate\Http\Request;


class VoucherController extends Controller
{

    public function index(Request $request)
    {
        $vouchers = Voucher::latest()->get();
        return view('backend.modules.vouchers.index', compact('vouchers'));
    }

    public function create(Request $request)
    {
        $products = Product::orderBy('product_name', 'ASC')->get();
        return view('backend.modules.vouchers.create', compact('products'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required|unique:vouchers,code',
            'amount' => 'required|numeric',
            'type' => 'required',
        ]);

        // dd(json_encode($request->product_promo, true));

        Voucher::create([
            'code' => $request->code,
            'type' => $request->type,
            'amount' => $request->amount,
            'count_app' => $request->count_app,
            'product_promo' => json_encode($request->product_promo),
        ]);

        return redirect('admin/vouchers')->with('success', 'New Voucher Code Added Successfully');
    }

    public function show(Request $request, $id)
    {
        $voucher = Voucher::findOrFail($id);
        return view('backend.modules.vouchers.show', compact('voucher'));
    }

    public function edit(Request $request, $id)
    {
        $voucher = Voucher::findOrFail($id);
        $products = Product::orderBy('product_name', 'ASC')->get();
        return view('backend.modules.vouchers.edit', compact('voucher', 'products'));
    }

    public function update(Request $request, $id)
    {
        $voucher = Voucher::findOrFail($id);

        $request->validate([
            'code' => 'required|unique:vouchers,code,' . $id,
            'amount' => 'required|numeric',
            'type' => 'required',
        ]);

        $voucher->update([
            'code' => $request->code,
            'type' => $request->type,
            'amount' => $request->amount,
            'count_app' => $request->count_app,
            'product_promo' => json_encode($request->product_promo),
        ]);
        
        return back()->with('success', 'Voucher Code Updated Successfully');
    }

    public function destroy(Request $request, $id)
    {
        $voucher = Voucher::findOrFail($id);
        $voucher->delete();
        return back()->with('success', 'Voucher Code Deleted Successfully');
    }
}
